@@ -36,10 +36,10 @@ class CSVFilterDia : public KoFilterDialog {
     Q_OBJECT
 
 public:
-    CSVFilterDia(QWidget *parent=0L, QString name=QString::null);
+    CSVFilterDia(QWidget *parent=0L, const char *name=0L);
     virtual ~CSVFilterDia() {}
 
-    virtual const QString state();
+    virtual QString state();
 
 private:
     QVButtonGroup *box;
