@@ -1,8 +1,6 @@
 #ifndef _kchartWIZARDSELECTCHARTSUBTYPEPAGE_H
 #define _kchartWIZARDSELECTCHARTSUBTYPEPAGE_H
 
-#include <qwidget.h>
-
 #include <kchartparams.h>
 #include <qradiobutton.h>
 
@@ -10,28 +8,19 @@ class QButtonGroup;
 class QPushButton;
 class KChartPart;
 
-class kchartWizardSelectChartSubTypePage : public QWidget
+class KChartWizardSelectChartSubTypePage : public QWidget
 {
   Q_OBJECT
-
 public:
-  kchartWizardSelectChartSubTypePage( QWidget* parent, KChartPart* chart );
+  KChartWizardSelectChartSubTypePage( QWidget* parent, KChartPart* chart );
 
-  bool createChildren();
   bool chartSubType;
 public slots:
   void apply();
-private slots:
-  void chartSubTypeSelected( int type );
 
 private:
   KChartPart* _chart;
   KChartType _charttype;
-  int _no;
-  QButtonGroup* _typeBG;
-  QPushButton* _normalbarsPB;
-  QPushButton* _barsontopPB;
-  QPushButton* _barsinfrontPB;
   QRadioButton *depth;
   QRadioButton *sum;
   QRadioButton *beside;
