@@ -1,13 +1,13 @@
 /* -*- C++ -*-
 
-  $Id: CreateTextCmd.h,v 1.3 2000/05/16 13:25:21 sattler Exp $
+  $Id: CreateTextCmd.h,v 1.5 2000/07/31 21:00:47 wtrobin Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
-  published by  
+  published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
@@ -15,7 +15,7 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU Library General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -25,7 +25,7 @@
 #ifndef CreateTextCmd_h_
 #define CreateTextCmd_h_
 
-#include "Command.h"
+#include <Command.h>
 
 class GDocument;
 class GText;
@@ -34,8 +34,8 @@ class CreateTextCmd : public Command {
   Q_OBJECT
 public:
   CreateTextCmd (GDocument* doc, GText* obj);
-  CreateTextCmd (GDocument* doc, const Coord& p, const char* str);
-  
+  CreateTextCmd (GDocument* doc, const Coord& p, const QString &str);
+
   ~CreateTextCmd ();
 
   void execute ();
