@@ -1,13 +1,13 @@
 /* -*- C++ -*-
 
-  $Id: CutCmd.h,v 1.5 2000/05/16 13:25:21 sattler Exp $
+  $Id: CutCmd.h,v 1.8 2000/07/30 20:44:19 wtrobin Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
-  published by  
+  published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
@@ -15,7 +15,7 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU Library General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -25,24 +25,27 @@
 #ifndef CutCmd_h_
 #define CutCmd_h_
 
-#include <list>
-#include "Command.h"
+#include <Command.h>
 
 class GDocument;
 class GObject;
 
 class CutCmd : public Command {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  CutCmd (GDocument* doc);
-  ~CutCmd ();
+    CutCmd (GDocument* doc);
+    ~CutCmd ();
 
-  void execute ();
-  void unexecute ();
+    void execute ();
+    void unexecute ();
 
 private:
-  GDocument* document;
-  list<std::pair<int, GObject*> > objects;
+    struct MyPair {
+        GObject *o;
+        int pos;
+    };
+    GDocument* document;
+    QList<MyPair> objects;
 };
 
 #endif
