@@ -1,13 +1,13 @@
 /* -*- C++ -*-
 
-  $Id: TranslateCmd.cc,v 1.5 2000/05/16 13:25:21 sattler Exp $
+  $Id: TranslateCmd.cc,v 1.6 2000/07/28 20:11:48 wtrobin Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
-  published by  
+  published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
@@ -15,17 +15,15 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU Library General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
 
-#include "TranslateCmd.h"
-#include "TranslateCmd.moc"
+#include <TranslateCmd.h>
 #include <klocale.h>
-#include <kapp.h>
 
 TranslateCmd::TranslateCmd (GDocument* doc, float x, float y) :
   ObjectManipCmd (doc, i18n("Translate")) {
@@ -39,7 +37,8 @@ void TranslateCmd::execute () {
   // save the states
   ObjectManipCmd::execute ();
 
-  for (unsigned int i = 0; i < objects.count (); i++) 
+  for (unsigned int i = 0; i < objects.count (); i++)
     objects[i]->transform (m, true);
 }
 
+#include <TranslateCmd.moc>
