@@ -19,6 +19,7 @@
 
 #include "styledia.h"
 #include "styledia.moc"
+#include "generalconfig.h"
 
 #include <kapp.h>
 #include <klocale.h>
@@ -127,6 +128,7 @@ StyleDia::StyleDia( QWidget* parent, const char* name, int flags_ )
     lockUpdate = true;
     setupTab1();
     setupTab2();
+    setupTab3();
     lockUpdate = false;
 
     if ( flags & SdPen )
@@ -192,10 +194,10 @@ void StyleDia::setupTab1()
     l->setFixedHeight( l->sizeHint().height() );
 
     clineBegin = new QComboBox( false, right, "lineBegin" );
-    clineBegin->insertItem( "Normal" );
-    clineBegin->insertItem( "Arrow" );
-    clineBegin->insertItem( "Square" );
-    clineBegin->insertItem( "Circle" );
+    clineBegin->insertItem( i18n("Normal") );
+    clineBegin->insertItem( i18n("Arrow") );
+    clineBegin->insertItem( i18n("Square") );
+    clineBegin->insertItem( i18n("Circle") );
     connect( clineBegin, SIGNAL( activated( int ) ),
 	     this, SLOT( updatePenConfiguration() ) );
 
@@ -203,10 +205,10 @@ void StyleDia::setupTab1()
     l->setFixedHeight( l->sizeHint().height() );
 
     clineEnd = new QComboBox( false, right, "lineEnd" );
-    clineEnd->insertItem( "Normal" );
-    clineEnd->insertItem( "Arrow" );
-    clineEnd->insertItem( "Square" );
-    clineEnd->insertItem( "Circle" );
+    clineEnd->insertItem( i18n("Normal") );
+    clineEnd->insertItem( i18n("Arrow") );
+    clineEnd->insertItem( i18n("Square") );
+    clineEnd->insertItem( i18n("Circle") );
     connect( clineEnd, SIGNAL( activated( int ) ),
 	     this, SLOT( updatePenConfiguration() ) );
 
@@ -229,6 +231,13 @@ void StyleDia::setupTab1()
 	tab->hide();
 }
 
+void StyleDia::setupTab3()
+{
+    PageConfigGeneral *w = new PageConfigGeneral( this );
+    sticky = w->checkboxSticky;
+    addTab( w , i18n( "&General" ) );
+}
+
 /*==============================================================*/
 void StyleDia::setupTab2()
 {
@@ -645,3 +654,14 @@ int StyleDia::getGYFactor()
 {
     return yfactor->value();
 }
+
+void StyleDia::setSticky( bool s )
+{
+    sticky->setChecked( s );
+}
+
+
+bool StyleDia::isSticky()
+{
+    return sticky->isChecked();
+}
