@@ -19,13 +19,14 @@
 
 #include <config.h>
 
-#include "koApplication.h"
-#include "koMainWindow.h"
-#include "koDocument.h"
-#include "koView.h"
-#include "koFilterManager.h"
-#include "koDocumentInfo.h"
-#include "koDocumentInfoDlg.h"
+#include <koApplication.h>
+#include <koMainWindow.h>
+#include <koDocument.h>
+#include <koView.h>
+#include <koFilterManager.h>
+#include <koDocumentInfo.h>
+#include <koDocumentInfoDlg.h>
+#include <koQueryTrader.h>
 
 #include <qkeycode.h>
 #include <qfile.h>
@@ -34,6 +35,7 @@
 #include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qsplitter.h>
+#include <qprinter.h>
 
 #include <kaboutdialog.h>
 #include <kstdaction.h>
@@ -49,18 +51,31 @@
 #include <kio/netaccess.h>
 #include <kkeydialog.h>
 #include <kedittoolbar.h>
+#include <kprogress.h>
 #include <kdebug.h>
+#include <kmimetype.h>
 
 #include <kparts/partmanager.h>
 #include <kparts/plugin.h>
 #include <kparts/event.h>
 
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif
 #include <stdlib.h>
 
-QList<KoMainWindow>* KoMainWindow::s_lstMainWindows = 0;
+class KoPartManager : public KParts::PartManager
+{
+public:
+  KoPartManager( QWidget * parent, const char * name = 0L )
+    : KParts::PartManager( parent, name ) {}
+  KoPartManager( QWidget *topLevel, QObject *parent, const char *name = 0L )
+    : KParts::PartManager( topLevel, parent, name ) {}
+  virtual bool eventFilter( QObject *obj, QEvent *ev )
+  {
+    if ( !obj->isWidgetType() || obj->inherits( "KoFrame" ) )
+      return false;
+    return KParts::PartManager::eventFilter( obj, ev );
+  }
+};
 
 class KoMainWindowPrivate
 {
@@ -68,29 +83,41 @@ public:
   KoMainWindowPrivate()
   {
     m_rootDoc = 0L;
-    m_rootViews = 0L;
     m_manager = 0L;
     bMainWindowGUIBuilt = false;
+    m_forQuit=false;
+    m_splitted=false;
     m_activePart = 0L;
     m_activeView = 0L;
-    m_splitViewActionList=0L;
     m_splitter=0L;
     m_orientation=0L;
     m_removeView=0L;
     m_toolbarList.setAutoDelete( true );
+    m_firstTime=true;
+    m_progress=0L;
+    m_paDocInfo = 0;
+    m_paSave = 0;
+    m_paSaveAs = 0;
+    m_paPrint = 0;
   }
   ~KoMainWindowPrivate()
   {
   }
 
   KoDocument *m_rootDoc;
-  QList<KoView> *m_rootViews;
+  QList<KoView> m_rootViews;
   KParts::PartManager *m_manager;
 
   KParts::Part *m_activePart;
   KoView *m_activeView;
 
-  QList<KAction> *m_splitViewActionList;
+  QLabel * statusBarLabel;
+  KProgress *m_progress;
+
+  QList<KAction> m_splitViewActionList;
+  // This additional list is needed, because we don't plug
+  // the first list, when an embedded view gets activated (Werner)
+  QList<KAction> m_veryHackyActionList;
   QSplitter *m_splitter;
   KSelectAction *m_orientation;
   KAction *m_removeView;
@@ -98,38 +125,49 @@ public:
   QList <KAction> m_toolbarList;
 
   bool bMainWindowGUIBuilt;
+  bool m_splitted;
+  bool m_forQuit;
+  bool m_firstTime;
+
+  KAction *m_paDocInfo;
+  KAction *m_paSave;
+  KAction *m_paSaveAs;
+  KAction *m_paPrint;
 };
 
 KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     : KParts::MainWindow( name )
 {
-    if ( !s_lstMainWindows )
-	s_lstMainWindows = new QList<KoMainWindow>;
-    s_lstMainWindows->append( this );
-
     d = new KoMainWindowPrivate;
 
-    d->m_manager = new KParts::PartManager( this );
+    d->m_manager = new KoPartManager( this );
     d->m_manager->setSelectionPolicy( KParts::PartManager::TriState );
     d->m_manager->setAllowNestedParts( true );
+    d->m_manager->setIgnoreScrollBars( true );
 
     connect( d->m_manager, SIGNAL( activePartChanged( KParts::Part * ) ),
-	     this, SLOT( slotActivePartChanged( KParts::Part * ) ) );
+             this, SLOT( slotActivePartChanged( KParts::Part * ) ) );
+
+    if ( instance )
+        setInstance( instance, false ); // don't load plugins! we don't want
+    // the part's plugins with this shell, even though we are using the
+    // part's instance! (Simon)
 
     setXMLFile( locate( "data", "koffice/koffice_shell.rc" ) );
+    setLocalXMLFile( locateLocal( "data", "koffice/koffice_shell.rc" ) );
 
     KStdAction::openNew( this, SLOT( slotFileNew() ), actionCollection(), "file_new" );
     KStdAction::open( this, SLOT( slotFileOpen() ), actionCollection(), "file_open" );
     m_recent = KStdAction::openRecent( this, SLOT(slotFileOpenRecent(const KURL&)), actionCollection() );
-    KStdAction::save( this, SLOT( slotFileSave() ), actionCollection(), "file_save" );
-    KStdAction::saveAs( this, SLOT( slotFileSaveAs() ), actionCollection(), "file_save_as" );
-    KStdAction::print( this, SLOT( slotFilePrint() ), actionCollection(), "file_print" );
+    d->m_paSave = KStdAction::save( this, SLOT( slotFileSave() ), actionCollection(), "file_save" );
+    d->m_paSaveAs = KStdAction::saveAs( this, SLOT( slotFileSaveAs() ), actionCollection(), "file_save_as" );
+    d->m_paPrint = KStdAction::print( this, SLOT( slotFilePrint() ), actionCollection(), "file_print" );
     KStdAction::close( this, SLOT( slotFileClose() ), actionCollection(), "file_close" );
     KStdAction::quit( this, SLOT( slotFileQuit() ), actionCollection(), "file_quit" );
 
-    (void) new KAction( i18n( "Document Information..." ), 0,
-			this, SLOT( slotDocumentInfo() ),
-			actionCollection(), "file_documentinfo" );
+    d->m_paDocInfo = new KAction( i18n( "&Document Information..." ), "documentinfo", 0,
+                        this, SLOT( slotDocumentInfo() ),
+                        actionCollection(), "file_documentinfo" );
 
     KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection(), "configurekeys" );
     KStdAction::configureToolbars( this, SLOT( slotConfigureToolbars() ), actionCollection(), "configuretoolbars" );
@@ -141,36 +179,48 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     KStdAction::aboutKDE( m_helpMenu, SLOT( aboutKDE() ), actionCollection(), "about_kde" );
     KStdAction::reportBug( m_helpMenu, SLOT( reportBug() ), actionCollection(), "report_bug" );
 
-    // set up the action list for the splitter stuff
-    d->m_splitViewActionList=new QList<KAction>;
-    d->m_splitViewActionList->append(new KAction(i18n("Split View"), 0, this, SLOT(slotSplitView()),
-						actionCollection(), "view_split"));
-    d->m_removeView=new KAction(i18n("Remove View"), 0, this, SLOT(slotRemoveView()),
-				actionCollection(), "view_rm_splitter");
-    d->m_splitViewActionList->append(d->m_removeView);
-    d->m_removeView->setEnabled(false);
-    d->m_orientation=new KSelectAction(i18n("Splitter Orientation"), 0, this, SLOT(slotSetOrientation()),
-				       actionCollection(), "view_splitter_orientation");
-    QStringList items;
-    items << i18n("Vertical")
-	  << i18n("Horizontal");
-    d->m_orientation->setItems(items);
-    d->m_splitViewActionList->append(d->m_orientation);
+    d->m_paDocInfo->setEnabled( false );
+    d->m_paSaveAs->setEnabled( false );
+    d->m_paSave->setEnabled( false );
+    d->m_paPrint->setEnabled( false );
 
-    if ( instance )
-      setInstance( instance );
+    d->m_splitter=new QSplitter(Qt::Vertical, this, "funky-splitter");
+    setCentralWidget( d->m_splitter );
+
+    // set up the action "list" for "Close all Views" (hacky :) (Werner)
+    d->m_veryHackyActionList.append(new KAction(i18n("&Close All Views"), 0, this,
+        SLOT(slotCloseAllViews()), actionCollection(), "view_closeallviews"));
+    // set up the action list for the splitter stuff
+    d->m_splitViewActionList.append(new KAction(i18n("&Split View"), 0,
+        this, SLOT(slotSplitView()),
+        actionCollection(), "view_split"));
+    d->m_removeView=new KAction(i18n("&Remove View"), 0,
+        this, SLOT(slotRemoveView()),
+        actionCollection(), "view_rm_splitter");
+    d->m_splitViewActionList.append(d->m_removeView);
+    d->m_removeView->setEnabled(false);
+    d->m_orientation=new KSelectAction(i18n("Splitter &Orientation"), 0,
+        this, SLOT(slotSetOrientation()),
+        actionCollection(), "view_splitter_orientation");
+    QStringList items;
+    items << i18n("&Vertical")
+          << i18n("&Horizontal");
+    d->m_orientation->setItems(items);
+    d->m_orientation->setCurrentItem(static_cast<int>(d->m_splitter->orientation()));
+    d->m_splitViewActionList.append(d->m_orientation);
+    d->m_splitViewActionList.append(new KActionSeparator(this));
 
     // Load list of recent files
     KConfig * config = instance ? instance->config() : KGlobal::config();
     m_recent->loadEntries( config );
     config->sync();
 
-    d->m_splitter=new QSplitter(Qt::Vertical, this, "funky-splitter");
-    setView( d->m_splitter );
+    createShellGUI();
+    d->bMainWindowGUIBuilt = true;
 
-    d->m_rootViews=new QList<KoView>;
-
-    buildMainWindowGUI();
+    // Status bar
+    d->statusBarLabel = new QLabel( statusBar() );
+    statusBar()->addWidget( d->statusBarLabel, 1, true );
 
     if (QApplication::desktop()->width() > 1100) // very big desktop ?
         resize( 900, 800 );
@@ -186,18 +236,18 @@ KoMainWindow::~KoMainWindow()
     if (d->m_rootDoc)
         d->m_rootDoc->removeShell(this);
 
-    KoView *view=d->m_rootViews->first();
-    for ( ; view!=0L; view=d->m_rootViews->next()) {
-	delete view;
-	view=0L;
+    if(d->m_rootViews.findRef(d->m_activeView)==-1) {
+        delete d->m_activeView;
+        d->m_activeView=0L;
     }
-    delete d->m_rootViews;
+    d->m_rootViews.setAutoDelete( true );
+    d->m_rootViews.clear();
 
     // We have to check if this was a root document.
     // -> We aren't allowed to delete the (embedded) document!
     // This has to be checked from queryClose, too :)
     if ( d->m_rootDoc && d->m_rootDoc->viewCount() == 0 &&
-	 !d->m_rootDoc->isEmbedded())
+         !d->m_rootDoc->isEmbedded())
     {
         kdDebug(30003) << "Destructor. No more views, deleting old doc " << d->m_rootDoc << endl;
         delete d->m_rootDoc;
@@ -209,13 +259,7 @@ KoMainWindow::~KoMainWindow()
     m_recent->saveEntries( config );
     config->sync();
 
-    if ( s_lstMainWindows )
-	s_lstMainWindows->removeRef( this );
-
     delete d->m_manager;
-    d->m_splitViewActionList->setAutoDelete(true);
-    d->m_splitViewActionList->clear();
-    delete d->m_splitViewActionList;
     delete d->m_splitter;
     d->m_splitter=0L;
     delete d;
@@ -223,9 +267,12 @@ KoMainWindow::~KoMainWindow()
 
 void KoMainWindow::setRootDocument( KoDocument *doc )
 {
+  if ( d->m_rootDoc == doc )
+    return;
+
   kdDebug(30003) <<  "KoMainWindow::setRootDocument this = " << this << " doc = " << doc << endl;
-  QList<KoView> *oldRootViews = new QList<KoView>(*d->m_rootViews);
-  d->m_rootViews->clear();
+  QList<KoView> oldRootViews = d->m_rootViews;
+  d->m_rootViews.clear();
   KoDocument *oldRootDoc = d->m_rootDoc;
 
   if ( oldRootDoc )
@@ -236,25 +283,29 @@ void KoMainWindow::setRootDocument( KoDocument *doc )
   if ( doc )
   {
     doc->setSelectable( false );
-    d->m_rootViews->append( doc->createView( d->m_splitter ) );
-    d->m_rootViews->current()->setPartManager( d->m_manager );
+    d->m_manager->addPart( doc, false );
+    d->m_rootViews.append( doc->createView( d->m_splitter ) );
+    d->m_rootViews.current()->setPartManager( d->m_manager );
 
-    d->m_rootViews->current()->show();
+    d->m_rootViews.current()->show();
     d->m_rootDoc->addShell( this );
     d->m_removeView->setEnabled(false);
+    d->m_orientation->setEnabled(false);
   }
 
+  bool enable = d->m_rootDoc != 0 ? true : false;
+  d->m_paDocInfo->setEnabled( enable );
+  d->m_paSave->setEnabled( enable );
+  d->m_paSaveAs->setEnabled( enable );
+  d->m_paPrint->setEnabled( enable );
+
   updateCaption();
 
-  d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->current() );
-  d->m_orientation->setCurrentItem(static_cast<int>(d->m_splitter->orientation()));
+  d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews.current() );
+
+  oldRootViews.setAutoDelete( true );
+  oldRootViews.clear();
 
-  if ( !oldRootViews->isEmpty() ) {
-    for(KoView *view=oldRootViews->first(); view!=0L; view=oldRootViews->next()) {
-      delete view;
-      view=0L;
-    }
-  }
   if ( oldRootDoc && oldRootDoc->viewCount() == 0 )
   {
     kdDebug(30003) << "No more views, deleting old doc " << oldRootDoc << endl;
@@ -262,11 +313,22 @@ void KoMainWindow::setRootDocument( KoDocument *doc )
   }
 }
 
-void KoMainWindow::setRootDocumentDirect( KoDocument *doc )
+void KoMainWindow::setRootDocumentDirect( KoDocument *doc, const QList<KoView> & views )
 {
   d->m_rootDoc = doc;
-  // maybe we want to add the KoView as parameter and set it into
-  // d->m_rootView but it doesn't seem used at all ?!? (David)
+  d->m_rootViews = views;
+  bool enable = d->m_rootDoc != 0 ? true : false;
+  d->m_paDocInfo->setEnabled( enable );
+  d->m_paSave->setEnabled( enable );
+  d->m_paSaveAs->setEnabled( enable );
+  d->m_paPrint->setEnabled( enable );
+}
+
+KoDocument* KoMainWindow::createDoc() const
+{
+    QCString mimetype=KoDocument::readNativeFormatMimeType();
+    KoDocumentEntry entry=KoDocumentEntry::queryByMimeType(mimetype);
+    return entry.createDoc();
 }
 
 void KoMainWindow::updateCaption()
@@ -278,29 +340,31 @@ void KoMainWindow::updateCaption()
   {
       QString caption;
       // Get caption from document info (title(), in about page)
-      if ( d->m_rootDoc->documentInfo() )
+      if ( rootDocument()->documentInfo() )
       {
-          KoDocumentInfoPage * page = d->m_rootDoc->documentInfo()->page( QString::fromLatin1("about"));
+          KoDocumentInfoPage * page = rootDocument()->documentInfo()->page( QString::fromLatin1("about"));
           if (page)
               caption = static_cast<KoDocumentInfoAbout *>(page)->title();
       }
       if ( caption.isEmpty() )
           // Fall back to document URL
-          caption = d->m_rootDoc->url().prettyURL();
+          caption = rootDocument()->url().prettyURL();
 
       // KTMW hides some of the functionality of kapp->makeStdCaption !
-      QWidget::setCaption( kapp->makeStdCaption( caption, true, d->m_rootDoc->isModified() ) );
+      QWidget::setCaption( kapp->makeStdCaption( caption, true, rootDocument()->isModified() ) );
   }
 }
 
 KoDocument *KoMainWindow::rootDocument() const
 {
-  return d->m_rootDoc;
+    return d->m_rootDoc;
 }
 
 KoView *KoMainWindow::rootView() const
 {
-  return d->m_rootViews->first();
+  if(d->m_rootViews.find(d->m_activeView)!=-1)
+    return d->m_activeView;
+  return d->m_rootViews.first();
 }
 
 KParts::PartManager *KoMainWindow::partManager()
@@ -308,52 +372,39 @@ KParts::PartManager *KoMainWindow::partManager()
   return d->m_manager;
 }
 
-KoMainWindow* KoMainWindow::firstMainWindow()
-{
-    if ( !s_lstMainWindows )
-	return 0;
-
-    return s_lstMainWindows->first();
-}
-
-KoMainWindow* KoMainWindow::nextMainWindow()
-{
-    if ( !s_lstMainWindows )
-	return 0;
-
-    return s_lstMainWindows->next();
-}
-
 bool KoMainWindow::openDocument( const KURL & url )
 {
     m_recent->addURL( url );
     KoDocument* doc = rootDocument();
-	
-    KoDocument* newdoc = createDoc();
+    KoDocument *newdoc=createDoc();
+    d->m_firstTime=true;
+    connect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     if ( !newdoc || !newdoc->openURL( url ) )
     {
-	delete newdoc;
-	return false;
+        newdoc->delayedDestruction();
+        return false;
     }
+    disconnect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
 
-    if ( doc && doc->isEmpty() )
+    if ( doc && doc->isEmpty() && !doc->isEmbedded() )
     {
         // Replace current empty document
-	setRootDocument( newdoc );
+        setRootDocument( newdoc );
     }
     else if ( doc && !doc->isEmpty() )
     {
         // Open in a new shell
         // (Note : could create the shell first and the doc next for this
         // particular case, that would give a better user feedback...)
-        KoMainWindow *s = newdoc->createShell();
-        s->show();
-        s->setRootDocument( newdoc );
+//       KoMainWindow *s = newdoc->createShell();
+        KoMainWindow *s = new KoMainWindow( newdoc->instance() );
+       s->show();
+       s->setRootDocument( newdoc );
     }
     else
     {
         // We had no document, set the new one
-        setRootDocument( newdoc );
+       setRootDocument( newdoc );
     }
     return true;
 }
@@ -361,6 +412,9 @@ bool KoMainWindow::openDocument( const KURL & url )
 bool KoMainWindow::saveDocument( bool saveas )
 {
     KoDocument* pDoc = rootDocument();
+    if(!pDoc)
+        return true;
+    connect(pDoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
 
     QCString _native_format = pDoc->nativeFormatMimeType();
 
@@ -369,12 +423,13 @@ bool KoMainWindow::saveDocument( bool saveas )
         KFileDialog *dialog=new KFileDialog(QString::null, QString::null, 0L, "file dialog", true);
         dialog->setCaption( i18n("Save document as") );
         KoFilterManager::self()->prepareDialog(dialog, KoFilterManager::Export,
-                                              _native_format, nativeFormatPattern(),
-                                              nativeFormatName(), true);
-	KURL newURL;
+                                               _native_format, nativeFormatPattern(),
+                                               nativeFormatName(), true);
+        KURL newURL;
 
-        bool bOk = true;
-	do {
+        bool bOk;
+        do {
+            bOk=true;
             if(dialog->exec()==QDialog::Accepted)
                 newURL=dialog->selectedURL();
             else
@@ -383,49 +438,64 @@ bool KoMainWindow::saveDocument( bool saveas )
                 break;
             }
 
-	    if ( newURL.isEmpty() )
+            if ( newURL.isEmpty() )
             {
                 bOk = false;
                 break;
             }
 
             // HACK - should we add extension() to KURL ?
-	    if ( QFileInfo( newURL.path() ).extension().isEmpty() ) {
-		// assume that the pattern ends with .extension
-		QString s( dialog->currentFilter() );
-		QString extension = s.mid( s.find( "." ) );
-		newURL.setPath( newURL.path() + extension );
-	    }
+            if ( QFileInfo( newURL.path() ).extension().isEmpty() ) {
+                // assume that the pattern ends with .extension
+                QString s( dialog->currentFilter() );
+                QString extension = s.mid( s.find( "." ) );
+                extension = extension.left( extension.find( " " ) );
 
-	    if ( KIO::NetAccess::exists( newURL ) ) { // this file exists => ask for confirmation
-		bOk = KMessageBox::questionYesNo( this,
-						  i18n("A document with this name already exists\n"\
-						       "Do you want to overwrite it ?"),
-						  i18n("Warning") ) == KMessageBox::Yes;
-	    }
+                newURL.setPath( newURL.path() + extension );
+            }
+
+            if ( KIO::NetAccess::exists( newURL ) ) { // this file exists => ask for confirmation
+                bOk = KMessageBox::questionYesNo( this,
+                                                  i18n("A document with this name already exists\n"\
+                                                       "Do you want to overwrite it ?"),
+                                                  i18n("Warning") ) == KMessageBox::Yes;
+            }
         } while ( !bOk );
         KoFilterManager::self()->cleanUp();
         delete dialog;
-        if (bOk)
-        {
+        if (bOk) {
             m_recent->addURL( newURL );
             bool ret = pDoc->saveAs( newURL );
             pDoc->setTitleModified();
+            disconnect(pDoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
             return ret;
         }
+        disconnect(pDoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
         return false;
     }
-    else
-      return pDoc->save();
+    else {
+        bool ret=pDoc->save();
+        disconnect(pDoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
+        return ret;
+    }
+}
+
+void KoMainWindow::closeEvent(QCloseEvent *e) {
+    if(queryClose()) {
+        setRootDocument(0L);
+        KParts::MainWindow::closeEvent(e);
+    }
 }
 
 bool KoMainWindow::queryClose()
 {
   if ( rootDocument() == 0 )
     return true;
-  kdDebug(30003) << "KoMainWindow::queryClose() viewcount=" << rootDocument()->viewCount() << endl;
-  if ( rootDocument()->viewCount() > 1 )
-    return true; // no, so no problem for closing
+  kdDebug(30003) << "KoMainWindow::queryClose() viewcount=" << rootDocument()->viewCount()
+                 << " shellcount=" << rootDocument()->shellCount() << endl;
+  if ( !d->m_forQuit && rootDocument()->shellCount() > 1 )
+    // there are more open, and we are closing just one, so no problem for closing
+    return true;
 
   // see DTOR for a descr. for the 2nd test
   if ( rootDocument()->isModified() &&
@@ -447,41 +517,30 @@ bool KoMainWindow::queryClose()
   return true;
 }
 
-bool KoMainWindow::closeAllDocuments()
-{
-    KoMainWindow* win = firstMainWindow();
-    for( ; win; win = nextMainWindow() )
-    {
-	if ( !win->queryClose() )
-	    return false;
-        else
-            win->setRootDocument( 0L );
-    }
-    return true;
-}
-
 void KoMainWindow::slotFileNew()
 {
     KoDocument* doc = rootDocument();
-
-    KoDocument* newdoc = createDoc();
+    KoDocument *newdoc=createDoc();
+    connect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     if ( !newdoc || !newdoc->initDoc() )
     {
-	delete newdoc;
-	return;
+        newdoc->delayedDestruction();
+        return;
     }
-    if ( doc && doc->isEmpty() )
+    if ( doc && doc->isEmpty() && !doc->isEmbedded() )
     {
-	setRootDocument( newdoc );
-	return;
+        setRootDocument( newdoc );
+        return;
     }
     else if ( doc && !doc->isEmpty() )
     {
-        KoMainWindow *s = newdoc->createShell();
+//        KoMainWindow *s = newdoc->createShell();
+        KoMainWindow *s = new KoMainWindow( newdoc->instance() );
         s->show();
         s->setRootDocument( newdoc );
-	return;
+        return;
     }
+    disconnect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     setRootDocument( newdoc );
     return;
 }
@@ -491,8 +550,8 @@ void KoMainWindow::slotFileOpen()
     KFileDialog *dialog=new KFileDialog(QString::null, QString::null, 0L, "file dialog", true);
     dialog->setCaption( i18n("Open document") );
     KoFilterManager::self()->prepareDialog(dialog, KoFilterManager::Import,
-                                           KoDocument::readNativeFormatMimeType(), nativeFormatPattern(),
-                                           nativeFormatName(), true);
+                                           KoDocument::readNativeFormatMimeType(),
+                                           nativeFormatPattern(), nativeFormatName(), true);
     KURL url;
     if(dialog->exec()==QDialog::Accepted)
         url=dialog->selectedURL();
@@ -502,7 +561,7 @@ void KoMainWindow::slotFileOpen()
     KoFilterManager::self()->cleanUp();
     delete dialog;
     if ( url.isEmpty() )
-	return;
+        return;
 
     (void) openDocument(url);
 }
@@ -524,10 +583,10 @@ void KoMainWindow::slotFileSaveAs()
 
 void KoMainWindow::slotDocumentInfo()
 {
-  if ( !d->m_rootDoc )
+  if ( !rootDocument() )
     return;
 
-  KoDocumentInfo *docInfo = d->m_rootDoc->documentInfo();
+  KoDocumentInfo *docInfo = rootDocument()->documentInfo();
 
   if ( !docInfo )
     return;
@@ -536,31 +595,49 @@ void KoMainWindow::slotDocumentInfo()
   if ( dlg->exec() )
   {
     dlg->save();
-    d->m_rootDoc->setModified( true );
-    d->m_rootDoc->setTitleModified();
+    rootDocument()->setModified( true );
+    rootDocument()->setTitleModified();
   }
 
   delete dlg;
 }
 
 void KoMainWindow::slotFileClose()
+{
+    if (queryClose())
+    {
+        setRootDocument( 0L ); // don't delete this shell when deleting the document
+        delete d->m_rootDoc;
+        d->m_rootDoc = 0L;
+        slotFileNew();
+    }
+}
+
+void KoMainWindow::slotFileQuit()
 {
     if ( queryClose() )
     {
         setRootDocument( 0L );
-	close();
+        close();
     }
 }
 
 void KoMainWindow::slotFilePrint()
 {
-}
+    if ( !rootView() )
+    {
+        kdDebug() << "KoMainWindow::slotFilePrint : No root view!" << endl;
+        return;
+    }
 
-void KoMainWindow::slotFileQuit()
-{
-    // The style guide says: 'quit' closes the window.
-    // (which it calls "Application", but this does not mean kapp->quit())
-    close();
+    QPrinter printer;
+
+    // ### TODO: apply global koffice settings here
+
+    rootView()->setupPrinter( printer );
+
+    if ( printer.setup( this ) )
+        rootView()->print( printer );
 }
 
 void KoMainWindow::slotConfigureKeys()
@@ -592,8 +669,8 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
 void KoMainWindow::slotHelpAbout()
 {
     KAboutDialog *dia = new KAboutDialog( KAboutDialog::AbtProduct | KAboutDialog::AbtTitle | KAboutDialog::AbtImageOnly,
-					  kapp->caption(),
-					  KDialogBase::Ok, KDialogBase::Ok, this, 0, true );
+                                          kapp->caption(),
+                                          KDialogBase::Ok, KDialogBase::Ok, this, 0, true );
     dia->setTitle( kapp->caption() );
     dia->setProduct( "", "pre-Beta1", "the KOffice Team", "1998-2000" );
     dia->setImage( locate( "data", "koffice/pics/koffice-logo.png" ) );
@@ -603,62 +680,80 @@ void KoMainWindow::slotHelpAbout()
 
 void KoMainWindow::slotSplitView() {
 
-    kdDebug(30003) << "KoMainWindow::slotSplitView() called" << endl;
-    d->m_rootViews->append(d->m_rootDoc->createView(d->m_splitter));
-    d->m_rootViews->current()->show();
-    d->m_rootViews->current()->setPartManager( d->m_manager );
-    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->current() );
+    d->m_splitted=true;
+    d->m_rootViews.append(d->m_rootDoc->createView(d->m_splitter));
+    d->m_rootViews.current()->show();
+    d->m_rootViews.current()->setPartManager( d->m_manager );
+    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews.current() );
     d->m_removeView->setEnabled(true);
+    d->m_orientation->setEnabled(true);
 }
 
+void KoMainWindow::slotCloseAllViews() {
+
+  d->m_forQuit=true;
+  if(queryClose()) {
+    KoDocument *doc=d->m_rootDoc;
+    // get the tompost parent document (save because of inherits())
+    while(doc && doc->isEmbedded())
+      doc = static_cast<KoDocument*>(doc->parent());
+    doc->delayedDestruction();
+  }
+  d->m_forQuit=false;
+}
+
+
 void KoMainWindow::slotRemoveView() {
 
-    kdDebug(30003) << "KoMainWindow::slotRemoveView() called" << endl;
-
     KoView *view;
-    if(d->m_rootViews->findRef(d->m_activeView)!=-1)
-        view=d->m_rootViews->current();
+    if(d->m_rootViews.findRef(d->m_activeView)!=-1)
+        view=d->m_rootViews.current();
     else
-	view=d->m_rootViews->first();
+        view=d->m_rootViews.first();
     view->hide();
-    d->m_rootViews->removeRef(view);
+    d->m_rootViews.removeRef(view);
 
-    if(d->m_rootViews->count()==1)
-	d->m_removeView->setEnabled(false);
+    if(d->m_rootViews.count()==1)
+    {
+        d->m_removeView->setEnabled(false);
+        d->m_orientation->setEnabled(false);
+    }
     delete view;
     view=0L;
-    d->m_rootViews->first()->setPartManager( d->m_manager );
-    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->first() );
+    d->m_rootViews.first()->setPartManager( d->m_manager );
+    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews.first() );
+
+    if(d->m_rootViews.count()==1)
+        d->m_splitted=false;
 }
 
 void KoMainWindow::slotSetOrientation() {
-
-    kdDebug(30003) << "KoMainWindow::slotSetOrientation() called" << endl;
     d->m_splitter->setOrientation(static_cast<Qt::Orientation>
-				  (d->m_orientation->currentItem()));
+                                  (d->m_orientation->currentItem()));
 }
 
+void KoMainWindow::slotProgress(int value) {
 
-void KoMainWindow::buildMainWindowGUI()
-{
-  KXMLGUIFactory *factory = guiFactory();
-  QValueList<KXMLGUIClient *> plugins;
-  QValueList<KXMLGUIClient *>::ConstIterator pIt, pEnd;
-  if ( !d->bMainWindowGUIBuilt )
-  {
-    factory->addClient( this );
-
-    KParts::GUIActivateEvent ev( true );
-    QApplication::sendEvent( this, &ev );
-
-    plugins = KParts::Plugin::pluginClients( this );
-    pIt = plugins.begin();
-    pEnd = plugins.end();
-    for (; pIt != pEnd; ++pIt )
-      factory->addClient( *pIt );
-
-    d->bMainWindowGUIBuilt = true;
-  }
+    if(value==-1) {
+        statusBar()->removeWidget(d->m_progress);
+        delete d->m_progress;
+        d->m_progress=0L;
+        d->m_firstTime=true;
+        return;
+    }
+    if(d->m_firstTime) {
+        statusBar()->removeWidget(d->m_progress);
+        delete d->m_progress;
+        d->m_progress=0L;
+        statusBar()->setMaximumHeight(statusBar()->height());
+        d->m_progress=new KProgress(statusBar());
+        //d->m_progress->setMaximumHeight(statusBar()->height());
+        statusBar()->addWidget( d->m_progress, 0, true );
+        d->m_progress->show();
+        d->m_firstTime=false;
+    }
+    d->m_progress->setValue(value);
+    kapp->processEvents();
 }
 
 void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
@@ -668,13 +763,11 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
   // to reimplement it because it works with an active part, whereas we work
   // with an active view _and_ an active part, depending for what.
   // Both are KXMLGUIClients, but e.g. the plugin query needs a QObject.
-
-
   kdDebug(30003) <<  "KoMainWindow::slotActivePartChanged( Part * newPart) newPart = " <<
     newPart << endl;
   kdDebug(30003) <<  "current active part is " << d->m_activePart << endl;
 
-  if ( d->m_activePart && d->m_activePart == newPart )
+  if ( d->m_activePart && d->m_activePart == newPart && !d->m_splitted )
   {
     kdDebug(30003) << "no need to change the GUI" << endl;
     return;
@@ -682,8 +775,7 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
 
   KXMLGUIFactory *factory = guiFactory();
 
-  QValueList<KXMLGUIClient *> plugins;
-  QValueList<KXMLGUIClient *>::ConstIterator pIt, pBegin, pEnd;
+  QList<KParts::Plugin> plugins;
 
   setUpdatesEnabled( false );
 
@@ -693,15 +785,13 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     QApplication::sendEvent( d->m_activePart, &ev );
     QApplication::sendEvent( d->m_activeView, &ev );
 
-    plugins = KParts::Plugin::pluginClients( d->m_activeView );
-    pIt = plugins.fromLast();
-    pBegin = plugins.begin();
-
-    for (; pIt != pBegin; --pIt )
-      factory->removeClient( *pIt );
-
-    if ( pIt != plugins.end() )
-      factory->removeClient( *pIt );
+    plugins = KParts::Plugin::pluginObjects( d->m_activeView );
+    KParts::Plugin *plugin = plugins.last();
+    while ( plugin )
+    {
+      factory->removeClient( plugin );
+      plugin = plugins.prev();
+    }
 
     factory->removeClient( d->m_activeView );
 
@@ -709,7 +799,8 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     d->m_toolbarList.clear(); // deletes the actions
   }
 
-  buildMainWindowGUI();
+  if ( !d->bMainWindowGUIBuilt )
+    createShellGUI();
 
   if ( newPart && d->m_manager->activeWidget() && d->m_manager->activeWidget()->inherits( "KoView" ) )
   {
@@ -723,14 +814,17 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     QApplication::sendEvent( d->m_activePart, &ev );
     QApplication::sendEvent( d->m_activeView, &ev );
 
-    plugins = KParts::Plugin::pluginClients( d->m_activeView );
-    pIt = plugins.begin();
-    pEnd = plugins.end();
-    for (; pIt != pEnd; ++pIt )
-      factory->addClient( *pIt );
+    plugins = KParts::Plugin::pluginObjects( d->m_activeView );
+    QListIterator<KParts::Plugin> pIt( plugins );
+    for (; pIt.current(); ++pIt )
+      factory->addClient( pIt.current() );
 
-    if(d->m_rootViews->findRef(d->m_activeView)!=-1)
-	factory->plugActionList(d->m_activeView, "view_split", *d->m_splitViewActionList );
+    // This gets plugged in even for embedded views!
+    factory->plugActionList(d->m_activeView, "view_closeallviews",
+                            d->m_veryHackyActionList);
+    // This one only for root views
+    if(d->m_rootViews.findRef(d->m_activeView)!=-1)
+        factory->plugActionList(d->m_activeView, "view_split", d->m_splitViewActionList );
 
     // Create and plug toolbar list for Settings menu
     QListIterator<KToolBar> it = toolBarIterator();
@@ -751,6 +845,51 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     d->m_activePart = 0L;
   }
   setUpdatesEnabled( true );
-  updateRects();
 }
-#include "koMainWindow.moc"
+
+QLabel * KoMainWindow::statusBarLabel() const
+{
+  return d->statusBarLabel;
+}
+
+QString KoMainWindow::nativeFormatName()
+{
+    QString serviceType;
+
+    if ( rootDocument() )
+        serviceType = QString::fromLatin1( rootDocument()->nativeFormatMimeType() );
+    else
+        serviceType = QString::fromLatin1( KoDocument::readNativeFormatMimeType() );
+
+    if ( serviceType.isEmpty() )
+        return QString::null;
+
+    KMimeType::Ptr mimeType = KMimeType::mimeType( serviceType );
+
+    if ( !mimeType )
+        return QString::null;
+
+    return mimeType->comment();
+}
+
+QString KoMainWindow::nativeFormatPattern()
+{
+    QString serviceType;
+
+    if ( rootDocument() )
+        serviceType = QString::fromLatin1( rootDocument()->nativeFormatMimeType() );
+    else
+        serviceType = QString::fromLatin1( KoDocument::readNativeFormatMimeType() );
+
+    if ( serviceType.isEmpty() )
+        return QString::null;
+
+    KMimeType::Ptr mimeType = KMimeType::mimeType( serviceType );
+
+    if ( !mimeType )
+        return QString::null;
+
+    return *mimeType->patterns().begin();
+}
+
+#include <koMainWindow.moc>
